@@ -1,52 +1,57 @@
 # Metabox colorset
 # Written by: harnir
 
-SetEnv Colorset-Name "Metabox"
-SetEnv Colorset-Author "harnir"
+SetEnv Colorset_Name "Metabox"
 
 # What colorsets do we use?
 Read $./colorset-definition
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
 # QuakeConsole, thumbnailed windows
-Colorset $[cs-quakeconsole] \
+Colorset $[infostore.cs_quakeconsole] \
 Foreground "black", Background "black", \
 Hilight "black", Shadow "black", \
 IconAlpha 70
 
 
-Colorset $[cs-panel-inactive] \
+Colorset $[infostore.cs_panel_inactive] \
 Foreground "black", Background "#eaeaea", \
 Tint "#eaeaea" 100, RootTransparent, \
 fgTint "black" 100, IconAlpha, IconTint
 
-Colorset $[cs-panel-active] \
+Colorset $[infostore.cs_panel_active] \
 Foreground "white", Background "darkgray", \
 Hilight "darkgray", Shadow "darkgray", \
 Tint "#4a5f7e" 100, RootTransparent
 
-Colorset $[cs-panel-wininactive] \
+Colorset $[infostore.cs_panel_wininactive] \
 Foreground "black", Background "#eaeaea", \
 Hilight "#444444", Shadow "#444444", \
 Tint "#eaeaea" 100, RootTransparent
 
-Colorset $[cs-panel-winactive] \
+Colorset $[infostore.cs_panel_winactive] \
 Foreground "white", Background "#4a5f7e", \
 Hilight "#666666", Shadow "#666666", \
 Tint "#4a5f7e" 100, RootTransparent
 
-Colorset $[cs-panel-border] \
+Colorset $[infostore.cs_panel_border] \
 Background "#333333"
 
-Colorset $[cs-menu-inactive] \
+Colorset $[infostore.cs_menu_inactive] \
 Foreground "black", Background "#eaeaea", \
 Hilight "black", Shadow "#777777", \
 Tint "#eaeaea" 100, RootTransparent
 
-Colorset $[cs-menu-active] \
+Colorset $[infostore.cs_menu_active] \
 Foreground "white", Background "#4a5f7e", \
 Hilight "white", Shadow "black"
 
+Colorset $[infostore.cs_icon_active] \
+Foreground "black", Background "#eaeaea", \
+Hilight "#eaeaea", Shadow "darkgray", \
+RootTransparent
+
+Colorset $[infostore.cs_transparent] Transparent, RootTransparent
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
 # Additional variables
@@ -55,4 +60,3 @@ SetEnv ExternalFontColor "gray40"
 
 SetEnv TrayerTint "0xeaeaea"
 SetEnv TrayerAlpha "0"
-
